#ifndef PERSON_H
#define PERSON_H

#include <string>
#include <cstdint>
#include <vector>

// Interface for Person class
struct Person {
 public:
  Person() = default; // default constructor
  Person(std::string name, uint8_t age); // overloaded constructor
  Person(const Person& person) = default;       // copy constructor

  ~Person() {
    std::cout << "called destructor\n";
  }

  // The default copy constructor is already generated, so we don't need the following line.
  // Person& operator=(const Person& that) = default;

  // Q: is making name/age private useful here?
  // why? why not?
  //
  // Also, note that we return `const T&` for some getters to avoid
  // copying but just return by value for age. That's because the age
  // is a small value!
  const std::string& getName() const;  // accessor/getter
  uint8_t getAge() const;       // accessor/getter
  const std::vector<std::string>& getAliases() const;

  void setName(std::string);    // mutator/setter
  void setAge(uint8_t);         // mutator/setter

 private:
  std::string name;
  // Q: why uint8_t?
  uint8_t age;

  std::vector<std::string> aliases;
};

// constructor overloading
inline Person::Person(std::string input_name, uint8_t age) :
  name(input_name),
  age(age)
{
  aliases.push_back(name);
}


#endif // PERSON_H
